==> okteta_0.25.4.orig.tar.xz: okteta-0.25.4/libs/kasten/gui/io/abstractmodelstreamencoderconfigeditor.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractmodelstreamencoderconfigeditor.h"

namespace Kasten {

AbstractModelStreamEncoderConfigEditor::AbstractModelStreamEncoderConfigEditor(QWidget* parent)
    : QWidget(parent)
    , d(nullptr)
{}

AbstractModelStreamEncoderConfigEditor::~AbstractModelStreamEncoderConfigEditor()
{
//     delete d;
}

bool AbstractModelStreamEncoderConfigEditor::isValid() const
{
    return true;
}

AbstractSelectionView* AbstractModelStreamEncoderConfigEditor::createPreviewView() const
{
    return nullptr;
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/gui/io/abstractmodelstreamencoderconfigeditor.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractmodelstreamencoderconfigeditor.hpp"

namespace Kasten {

class AbstractModelStreamEncoderConfigEditorPrivate
{
};


AbstractModelStreamEncoderConfigEditor::AbstractModelStreamEncoderConfigEditor(QWidget* parent)
    : QWidget(parent)
{}

AbstractModelStreamEncoderConfigEditor::~AbstractModelStreamEncoderConfigEditor() = default;

bool AbstractModelStreamEncoderConfigEditor::isValid() const
{
    return true;
}

AbstractSelectionView* AbstractModelStreamEncoderConfigEditor::createPreviewView() const
{
    return nullptr;
}

}
